@@ -89,24 +89,12 @@ class TokenUtil(object):
         return token
 
 
-class AuthConfig(object):
-    def __init__(self, config_dict):
-        self.PRESALYTICS = config_dict
-
-
 class AuthenticationMixIn(object):
     def __init__(self, parent: 'Client', config=None, config_file=None, ignore_api_exceptions=False, **kwargs):
         self.parent: 'Client' = weakref.ref(parent)
         self._ignore_api_exceptions = ignore_api_exceptions
         super(AuthenticationMixIn, self).__init__(**kwargs)
 
-    def get_auth_header(self):
-        self.parent.refresh_token()
-        auth_header = {
-            "Authorization": "Bearer " + self.parent.token_util.token["access_token"]
-        }
-        return auth_header
-
     def call_api(
             self, resource_path, method,
             path_params=None, query_params=None, header_params=None,
@@ -119,7 +107,7 @@ class AuthenticationMixIn(object):
         rather than at class initialized (good for ipython notebooks)
         """
 
-        auth_header = self.get_auth_header()
+        auth_header = self.parent().get_auth_header()
         if header_params is not None:
             header_params.update(auth_header)
         else:
@@ -151,8 +139,8 @@ class AuthenticationMixIn(object):
         if self.configuration is None:
             raise presalytics.lib.exceptions.MissingConfigException("Base API not yet configured, please reconstruct API initialization")
         self.user_agent = AuthenticationMixIn._get_user_agent
-        if bool(self.auth_config.PRESALYTICS['HOSTS']):
-            self.set_host(self.parent.auth_config.PRESALYTICS['HOSTS'])
+        if presalytics.CONFIG.get("HOSTS", None):
+            self.set_host(presalytics.CONFIG.get('HOSTS'))
 
     @staticmethod
     def get_user_agent():
