@@ -4,6 +4,7 @@ import presalytics.lib.exceptions
 
 script_map = {
     'd3': 'https://cdnjs.cloudflare.com/ajax/libs/d3/5.12.0/d3.min.js',
+    'd3v3': 'https://cdnjs.cloudflare.com/ajax/libs/d3/3.5.17/d3.min.js',
     'reveal': {
         'base': 'https://cdnjs.cloudflare.com/ajax/libs/reveal.js/3.6.0/js/reveal.min.js',
         'marked': 'https://cdnjs.cloudflare.com/ajax/libs/reveal.js/3.6.0/plugin/markdown/marked.js',
@@ -15,7 +16,8 @@ script_map = {
         'print': 'https://cdnjs.cloudflare.com/ajax/libs/reveal.js/3.6.0/plugin/print-pdf/print-pdf.min.js'
 
     },
-    'mpld3': 'https://raw.githubusercontent.com/mpld3/mpld3/master/mpld3/js/mpld3.v0.3.1.dev1.min.js',
+    'mpld3': 'https://presalytics.io/static/mpld3/mpld3.min.js',
+    'ooxml': 'https://presalytics.io/static/ooxml/ooxml.js'
 }
 
 
