@@ -21,7 +21,7 @@ class TestClient(unittest.TestCase):
         """
         client = presalytics.client.api.Client(config_file=self.config_file)
         username = os.environ["PRESALYTICS_USERNAME"]
-        self.assertEqual(client.doc_converter.api_client.username, username)
+        self.assertEqual(client.username, username)
         self.assertEqual(client.ooxml_automation.api_client.configuration.host, os.environ["OOXML_AUTOMATION_HOST"])
 
     def test_module_config(self):
